==> roccat-tools-1.0.0.tar.bz2: roccat-tools-1.0.0/libroccatwidget/roccat_macro_editor_macros_frame.h <==
#ifndef __ROCCAT_MACRO_EDITOR_MACROS_FRAME_H__
#define __ROCCAT_MACRO_EDITOR_MACROS_FRAME_H__

/*
 * This file is part of roccat-tools.
 *
 * roccat-tools is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * roccat-tools is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with roccat-tools. If not, see <http://www.gnu.org/licenses/>.
 */

#include "roccat/roccat.h"
#include <gtk/gtk.h>

G_BEGIN_DECLS

#define ROCCAT_MACRO_EDITOR_MACROS_FRAME_TYPE (roccat_macro_editor_macros_frame_get_type())
#define ROCCAT_MACRO_EDITOR_MACROS_FRAME(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), ROCCAT_MACRO_EDITOR_MACROS_FRAME_TYPE, RoccatMacroEditorMacrosFrame))
#define IS_ROCCAT_MACRO_EDITOR_MACROS_FRAME(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), ROCCAT_MACRO_EDITOR_MACROS_FRAME_TYPE))

typedef struct _RoccatMacroEditorMacrosFrame RoccatMacroEditorMacrosFrame;
typedef struct _RoccatMacroEditorMacrosFramePrivate RoccatMacroEditorMacrosFramePrivate;

struct _RoccatMacroEditorMacrosFrame {
	GtkFrame parent;
	RoccatMacroEditorMacrosFramePrivate *priv;
};

GType roccat_macro_editor_macros_frame_get_type(void);

GtkWidget *roccat_macro_editor_macros_frame_new(void);

RoccatMacros *roccat_macro_editor_macros_frame_get_macros(RoccatMacroEditorMacrosFrame *macros_frame);
gboolean roccat_macro_editor_macros_frame_add_macros(RoccatMacroEditorMacrosFrame *macros_frame, RoccatMacros *roccat_macros);
void roccat_macro_editor_macros_frame_clear(RoccatMacroEditorMacrosFrame *macros_frame);

G_END_DECLS

#endif

==> roccat-tools-1.4.0.tar.bz2: roccat-tools-1.4.0/libroccatwidget/roccat_macro_editor_macros_frame.h <==
#ifndef __ROCCAT_MACRO_EDITOR_MACROS_FRAME_H__
#define __ROCCAT_MACRO_EDITOR_MACROS_FRAME_H__

/*
 * This file is part of roccat-tools.
 *
 * roccat-tools is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * roccat-tools is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with roccat-tools. If not, see <http://www.gnu.org/licenses/>.
 */

#include "roccat_macros.h"
#include <gtk/gtk.h>

G_BEGIN_DECLS

#define ROCCAT_MACRO_EDITOR_MACROS_FRAME_TYPE (roccat_macro_editor_macros_frame_get_type())
#define ROCCAT_MACRO_EDITOR_MACROS_FRAME(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), ROCCAT_MACRO_EDITOR_MACROS_FRAME_TYPE, RoccatMacroEditorMacrosFrame))
#define IS_ROCCAT_MACRO_EDITOR_MACROS_FRAME(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), ROCCAT_MACRO_EDITOR_MACROS_FRAME_TYPE))

typedef struct _RoccatMacroEditorMacrosFrame RoccatMacroEditorMacrosFrame;
typedef struct _RoccatMacroEditorMacrosFramePrivate RoccatMacroEditorMacrosFramePrivate;

struct _RoccatMacroEditorMacrosFrame {
	GtkFrame parent;
	RoccatMacroEditorMacrosFramePrivate *priv;
};

GType roccat_macro_editor_macros_frame_get_type(void);

GtkWidget *roccat_macro_editor_macros_frame_new(void);

RoccatMacros *roccat_macro_editor_macros_frame_get_macros(RoccatMacroEditorMacrosFrame *macros_frame);
gboolean roccat_macro_editor_macros_frame_add_macros(RoccatMacroEditorMacrosFrame *macros_frame, RoccatMacros *roccat_macros);
void roccat_macro_editor_macros_frame_clear(RoccatMacroEditorMacrosFrame *macros_frame);

G_END_DECLS

#endif
